```
Usage: vcd gateway sub-allocate-ip add [OPTIONS] <name>

Options:
  -e, --external-network <external network>
                                  external network connected to the gateway.
                                  [required]
  -i, --ip-range <ip range>       ip ranges used for static pool allocation in
                                  the network.  [required]
  -h, --help                      Show this message and exit.

```
